@@ -196,7 +196,7 @@ def camelize(word):
         The modified string.
     """
     return ''.join(w[0].upper() + w[1:]
-                   for w in re.sub('[^A-Z^a-z^0-9^:]+', ' ', word).split(' '))
+                   for w in re.sub('[^A-Z^a-z^0-9^:]+', ' ', word).strip().split(' '))
 
 
 def underscore(word):
@@ -284,7 +284,7 @@ def serialize(value, element):
 
 
 def to_json(obj, root='object'):
-    """Convert a dictionary or list to an JSON string.
+    """Convert a dictionary, list or Collection to an JSON string.
 
     Args:
         obj: The object to serialize.
